You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jcs-dev@jakarta.apache.org by as...@apache.org on 2008/08/14 00:14:48 UTC

svn commit: r685702 [1/5] - in /jakarta/jcs/trunk: ./ src/java/org/apache/jcs/auxiliary/ src/java/org/apache/jcs/auxiliary/disk/ src/java/org/apache/jcs/auxiliary/disk/block/ src/java/org/apache/jcs/auxiliary/disk/indexed/ src/java/org/apache/jcs/auxil...

Author: asmuts
Date: Wed Aug 13 15:14:46 2008
New Revision: 685702

URL: http://svn.apache.org/viewvc?rev=685702&view=rev
Log:
Adding the ability to inject both event loggers and custom serializers into auxiliaries.  The event loggers will make JCS far easier to monitor.  The custom serializers will allow you to do things such as have JCS compress your items prior to storage.  This is still a work in progress.  I have more to do.

Added:
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/behavior/ICacheEventLogger.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/OptionConverter.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/java/org/apache/jcs/config/OptionConverter.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/PropertySetter.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetter.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/PropertySetterException.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/config/package.html   (props changed)
      - copied unchanged from r682483, jakarta/jcs/trunk/src/java/org/apache/jcs/config/package.html
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/MockAuxiliaryCache.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/AuxiliaryCacheMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/MockCacheEventLogger.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/MockRemoteCacheClient.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheClientMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/MockRemoteCacheListener.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheListenerMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/MockRemoteCacheService.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheServiceMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/CompositeCacheConfiguratorUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/MockCacheEventLogger.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/MockCompositeCacheManager.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/CompositeCacheManagerMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/MockElementSerializer.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/memory/MockMemoryCache.java   (contents, props changed)
      - copied, changed from r682483, jakarta/jcs/trunk/src/test/org/apache/jcs/engine/memory/MemoryCacheMockImpl.java
Removed:
    jakarta/jcs/trunk/src/java/org/apache/jcs/config/OptionConverter.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetter.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/config/PropertySetterException.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/config/package.html
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/AuxiliaryCacheMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheClientMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheListenerMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheServiceMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/CompositeCacheManagerMockImpl.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/memory/MemoryCacheMockImpl.java
Modified:
    jakarta/jcs/trunk/   (props changed)
    jakarta/jcs/trunk/maven.xml
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AbstractAuxiliaryCacheAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/AbstractDiskCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/block/BlockDiskCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/hsql/HSQLDiskCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLTableOptimizer.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWait.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWaitFacade.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/behavior/ILateralCacheManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/socket/tcp/LateralTCPCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheFailoverRunner.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheListener.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheNoWait.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/RemoteCacheNoWaitFacade.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/behavior/IRemoteCacheClient.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/server/RemoteCacheServer.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/server/RemoteCacheServerAttributes.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/server/RemoteCacheServerFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/remote/server/RemoteCacheStartupServlet.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/CacheEventQueueFactory.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/behavior/ICacheElementSerialized.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/behavior/IElementSerializer.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheConfigurator.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/control/CompositeCacheManager.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/engine/memory/AbstractMemoryCache.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/access/AbstractJCSWorkerHelper.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/serialization/StandardSerializer.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUMap.java
    jakarta/jcs/trunk/src/java/org/apache/jcs/utils/struct/LRUMapEntry.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/lateral/socket/tcp/TestTCPLateralUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheClientTester.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheListenerUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheNoWaitUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteCacheUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/RemoteUtilsUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/TestRemoteCache.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/ZombieRemoteCacheServiceUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/server/BasicRemoteCacheClientServerUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/auxiliary/remote/server/RemoteCacheServerUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/CompositeCacheDiskUsageUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/control/CompositeCacheUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/engine/memory/shrinking/ShrinkerThreadUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/utils/serialization/SerializationConversionUtilUnitTest.java
    jakarta/jcs/trunk/src/test/org/apache/jcs/utils/serialization/StandardSerializerUnitTest.java

Propchange: jakarta/jcs/trunk/
------------------------------------------------------------------------------
--- svn:ignore (original)
+++ svn:ignore Wed Aug 13 15:14:46 2008
@@ -1,11 +1,12 @@
-*~
-target
-test-reports
-.classpath
-.project
-*.log
-jars
-junit*.properties
-checkstyle-license.txt
-CodeWrestler.excludes
-*.ser
+*~
+target
+test-reports
+.classpath
+.project
+*.log
+jars
+junit*.properties
+checkstyle-license.txt
+CodeWrestler.excludes
+*.ser
+.settings

Modified: jakarta/jcs/trunk/maven.xml
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/maven.xml?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/maven.xml (original)
+++ jakarta/jcs/trunk/maven.xml Wed Aug 13 15:14:46 2008
@@ -68,7 +68,7 @@
   <!-- The eclipse goal runs .project and .classpath generation -->
   <!-- I want to prevent the .project file genreation, so -->
   <!-- the ant external tool builder will not get wiped out. -->
-  <goal name="eclipse:generate-project">
+  <goal name="SKIPeclipse:generate-project">
     <!-- do nothing -->
     <ant:echo>Not generating the .project file.</ant:echo>
   </goal>

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AbstractAuxiliaryCacheAttributes.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AbstractAuxiliaryCacheAttributes.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AbstractAuxiliaryCacheAttributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AbstractAuxiliaryCacheAttributes.java Wed Aug 13 15:14:46 2008
@@ -1,69 +1,55 @@
 package org.apache.jcs.auxiliary;
 
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for additional information regarding
+ * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the License. You may obtain a
+ * copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 
 import org.apache.jcs.engine.behavior.ICacheEventQueue;
 
-/**
+/*
  * This has common attributes used by all auxiliaries.
- * <p>
- * @author aaronsm
- *
  */
 public abstract class AbstractAuxiliaryCacheAttributes
     implements AuxiliaryCacheAttributes
 {
-    /**
-     * cacheName
-     */
+    /** Don't change     */
+    private static final long serialVersionUID = -6594609334959187673L;
+
+    /** cacheName */
     protected String cacheName;
 
-    /**
-     * name
-     */
+    /** name  */
     protected String name;
 
-    /**
-     * eventQueueType -- pooled or single threaded
-     */
+    /** eventQueueType -- pooled or single threaded  */
     protected int eventQueueType;
 
-    /**
-     * Named when pooled
-     */
+    /** Named when pooled */
     protected String eventQueuePoolName;
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#setCacheName(java.lang.String)
+    /**
+     * @param name
      */
-    public void setCacheName( String s )
+    public void setCacheName( String name )
     {
-        this.cacheName = s;
+        this.cacheName = name;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#getCacheName()
+    /**
+     * Gets the cacheName attribute of the AuxiliaryCacheAttributes object
+     * <p>
+     * @return The cacheName value
      */
     public String getCacheName()
     {
@@ -80,20 +66,23 @@
         this.name = s;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#getName()
+    /**
+     * Gets the name attribute of the AuxiliaryCacheAttributes object
+     * <p>
+     * @return The name value
      */
     public String getName()
     {
         return this.name;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#setEventQueueType(java.lang.String)
+    /**
+     * SINGLE is the default. If you choose POOLED, the value of
+     * EventQueuePoolName will be used
+     * <p>
+     * @param s
+     *            SINGLE or POOLED
+     * @return
      */
     public void setEventQueueType( String s )
     {
@@ -116,10 +105,8 @@
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#getEventQueueType()
+    /**
+     * @return SINGLE or POOLED
      */
     public String getEventQueueType()
     {
@@ -133,34 +120,37 @@
         }
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#getEventQueueTypeFactoryCode()
+    /**
+     * Returns the value used by the factory.
+     * <p>
+     * @return code
      */
     public int getEventQueueTypeFactoryCode()
     {
         return this.eventQueueType;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#setEventQueuePoolName(java.lang.String)
+    /**
+     * If you choose a POOLED event queue type, the value of EventQueuePoolName
+     * will be used. This is ignored if the pool type is SINGLE
+     * <p>
+     * @param s
+     *            SINGLE or POOLED
+     * @return
      */
     public void setEventQueuePoolName( String s )
     {
         eventQueuePoolName = s;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheAttributes#getEventQueuePoolName()
+    /**
+     * Sets the pool name to use. If a pool is not found by this name, the
+     * thread pool manager will return a default configuration.
+     * <p>
+     * @return name of thread pool to use for this auxiliary
      */
     public String getEventQueuePoolName()
     {
         return eventQueuePoolName;
     }
-
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCache.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCache.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCache.java Wed Aug 13 15:14:46 2008
@@ -23,6 +23,8 @@
 import java.util.Set;
 
 import org.apache.jcs.engine.behavior.ICache;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 import org.apache.jcs.engine.stats.behavior.IStats;
 
 /**
@@ -56,4 +58,19 @@
      * @return the attributes for the auxiliary cache
      */
     AuxiliaryCacheAttributes getAuxiliaryCacheAttributes();
+
+    /**
+     * Allows you to inject a custom serializer. A good example would be a compressing standard
+     * serializer.
+     * <p>
+     * @param elementSerializer
+     */
+    void setElementSerializer( IElementSerializer elementSerializer );
+
+    /**
+     * Every Auxiliary must allow for the use of an event logger.
+     * <p>
+     * @param cacheEventLogger
+     */
+    void setCacheEventLogger( ICacheEventLogger cacheEventLogger );
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheAttributes.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheAttributes.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheAttributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheAttributes.java Wed Aug 13 15:14:46 2008
@@ -1,121 +1,102 @@
 package org.apache.jcs.auxiliary;
 
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for additional information regarding
+ * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the License. You may obtain a
+ * copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 
 import java.io.Serializable;
 
 /**
- * This is a nominal interface that auxiliary cache attributes should
- * implement. This allows the auxiliary mangers to share a common interface.
- *
+ * This is a nominal interface that auxiliary cache attributes should implement. This allows the
+ * auxiliary mangers to share a common interface.
  */
 public interface AuxiliaryCacheAttributes
     extends Cloneable, Serializable
 {
-
-    /**
-     * Does not use a thread pool.
-     */
+    /** Does not use a thread pool. */
     public static final String SINGLE_QUEUE_TYPE = "SINGLE";
 
-    /**
-     * Uses a thread pool
-     */
+    /** Uses a thread pool. */
     public static final String POOLED_QUEUE_TYPE = "POOLED";
 
     /**
      * Sets the name of the cache, referenced by the appropriate manager.
-     *
-     * @param s
-     *            The new cacheName value
+     * <p>
+     * @param s The new cacheName value
      */
     public void setCacheName( String s );
 
     /**
      * Gets the cacheName attribute of the AuxiliaryCacheAttributes object
-     *
+     * <p>
      * @return The cacheName value
      */
     public String getCacheName();
 
     /**
      * Name known by by configurator
-     *
-     * @param s
-     *            The new name value
+     * <p>
+     * @param s The new name value
      */
     public void setName( String s );
 
     /**
      * Gets the name attribute of the AuxiliaryCacheAttributes object
-     *
+     * <p>
      * @return The name value
      */
     public String getName();
 
     /**
-     * SINGLE is the default. If you choose POOLED, the value of
-     * EventQueuePoolName will be used
-     *
-     * @param s
-     *            SINGLE or POOLED
-     * @return
+     * SINGLE is the default. If you choose POOLED, the value of EventQueuePoolName will be used
+     * <p>
+     * @param s SINGLE or POOLED
      */
     public void setEventQueueType( String s );
 
     /**
-     *
      * @return SINGLE or POOLED
      */
     public String getEventQueueType();
 
     /**
      * Returns the value used by the factory.
-     *
-     * @return
+     * <p>
+     * @return code
      */
     public int getEventQueueTypeFactoryCode();
 
     /**
-     * If you choose a POOLED event queue type, the value of EventQueuePoolName
-     * will be used. This is ignored if the pool type is SINGLE
-     *
-     * @param s
-     *            SINGLE or POOLED
-     * @return
+     * If you choose a POOLED event queue type, the value of EventQueuePoolName will be used. This
+     * is ignored if the pool type is SINGLE
+     * <p>
+     * @param s SINGLE or POOLED
      */
     public void setEventQueuePoolName( String s );
 
     /**
-     * Sets the pool name to use. If a pool is not found by this name, the
-     * thread pool manager will return a default configuration.
-     *
+     * Sets the pool name to use. If a pool is not found by this name, the thread pool manager will
+     * return a default configuration.
+     * <p>
      * @return name of thread pool to use for this auxiliary
      */
     public String getEventQueuePoolName();
 
     /**
-     * Description of the Method
-     *
-     * @return
+     * Clones
+     * <p>
+     * @return a copy
      */
     public AuxiliaryCacheAttributes copy();
-
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheManager.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheManager.java Wed Aug 13 15:14:46 2008
@@ -30,10 +30,9 @@
 public interface AuxiliaryCacheManager
     extends ICacheType
 {
-
     /**
      * Return the appropriate auxiliary cache for this region.
-     *
+     * <p>
      * @param cacheName
      * @return AuxiliaryCache
      */
@@ -41,9 +40,9 @@
 
     /**
      * This allows the cache manager to be plugged into the auxiliary caches,
-     * rather then having them get it themselves. Cache maangers can be mocked
+     * rather then having them get it themselves. Cache managers can be mocked
      * out and the auxiliaries will be easier to test.
-     *
+     * <p>
      * @param cacheName
      * @param cacheManager
      * @return AuxiliaryCache

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/AbstractDiskCache.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/AbstractDiskCache.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/AbstractDiskCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/AbstractDiskCache.java Wed Aug 13 15:14:46 2008
@@ -38,8 +38,10 @@
 import org.apache.jcs.engine.CacheInfo;
 import org.apache.jcs.engine.behavior.ICache;
 import org.apache.jcs.engine.behavior.ICacheElement;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICacheEventQueue;
 import org.apache.jcs.engine.behavior.ICacheListener;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 import org.apache.jcs.engine.stats.StatElement;
 import org.apache.jcs.engine.stats.Stats;
 import org.apache.jcs.engine.stats.behavior.IStatElement;
@@ -49,19 +51,22 @@
 
 /**
  * Abstract class providing a base implementation of a disk cache, which can be easily extended to
- * implement a disk cache for a specific perstistence mechanism.
+ * implement a disk cache for a specific persistence mechanism.
  * <p>
  * When implementing the abstract methods note that while this base class handles most things, it
- * does not acquire or release any locks. Implementations should do so as neccesary. This is mainly
- * done to minimize the time speant in critical sections.
+ * does not acquire or release any locks. Implementations should do so as necessary. This is mainly
+ * done to minimize the time spent in critical sections.
  * <p>
  * Error handling in this class needs to be addressed. Currently if an exception is thrown by the
- * persistence mechanism, this class destroys the event queue. Should it also destory purgatory?
+ * persistence mechanism, this class destroys the event queue. Should it also destroy purgatory?
  * Should it dispose itself?
  */
 public abstract class AbstractDiskCache
     implements AuxiliaryCache, Serializable
 {
+    /** Don't change. */
+    private static final long serialVersionUID = 6541664080877628324L;
+
     /** The logger */
     private static final Log log = LogFactory.getLog( AbstractDiskCache.class );
 
@@ -74,7 +79,7 @@
      * serializing the elements to persistent storage queued for later.
      * <p>
      * If the elements are pulled into the memory cache while the are still in purgatory, writing to
-     * disk can be cancelled.
+     * disk can be canceled.
      */
     protected Map purgatory = new HashMap();
 
@@ -106,10 +111,16 @@
      */
     private WriterPreferenceReadWriteLock removeAllLock = new WriterPreferenceReadWriteLock();
 
+    /** An optional event logger */
+    protected ICacheEventLogger cacheEventLogger;
+    
+    /** The serializer. */
+    protected IElementSerializer elementSerializer;    
+
     // ----------------------------------------------------------- constructors
 
     /**
-     * Construc the abstract disk cache, create event queues and purgatory.
+     * Construct the abstract disk cache, create event queues and purgatory.
      * <p>
      * @param attr
      */
@@ -306,7 +317,8 @@
      * Gets multiple items from the cache based on the given set of keys.
      * <p>
      * @param keys
-     * @return a map of Serializable key to ICacheElement element, or an empty map if there is no data in cache for any of these keys
+     * @return a map of Serializable key to ICacheElement element, or an empty map if there is no
+     *         data in cache for any of these keys
      */
     public final Map getMultiple( Set keys )
     {
@@ -411,11 +423,11 @@
      * <p>
      * Disposal proceeds in several steps.
      * <ol>
-     * <li> Prior to this call the Composite cache dumped the memory into the disk cache. If it is
+     * <li>Prior to this call the Composite cache dumped the memory into the disk cache. If it is
      * large then we need to wait for the event queue to finish.
-     * <li> Wait until the event queue is empty of until the configured ShutdownSpoolTimeLimit is
+     * <li>Wait until the event queue is empty of until the configured ShutdownSpoolTimeLimit is
      * reached.
-     * <li> Call doDispose on the concrete impl.
+     * <li>Call doDispose on the concrete impl.
      * </ol>
      */
     public final void dispose()
@@ -552,6 +564,27 @@
     }
 
     /**
+     * Allows it to be injected.
+     * <p>
+     * @param cacheEventLogger
+     */
+    public void setCacheEventLogger( ICacheEventLogger cacheEventLogger )
+    {
+        this.cacheEventLogger = cacheEventLogger;
+    }
+
+    /**
+     * Allows you to inject a custom serializer. A good example would be a compressing standard
+     * serializer.
+     * <p>
+     * @param elementSerializer
+     */
+    public void setElementSerializer( IElementSerializer elementSerializer )
+    {
+        this.elementSerializer = elementSerializer;
+    }
+    
+    /**
      * Cache that implements the CacheListener interface, and calls appropriate methods in its
      * parent class.
      */

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/block/BlockDiskCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/block/BlockDiskCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/block/BlockDiskCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/block/BlockDiskCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -24,7 +24,9 @@
 import org.apache.jcs.auxiliary.AuxiliaryCache;
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
  * Creates disk cache instances.
@@ -35,7 +37,7 @@
     /** The logger */
     private final static Log log = LogFactory.getLog( BlockDiskCacheFactory.class );
 
-    /** The auxiliary name */
+    /** The auxiliary name. The composite cache manager keeps this in a map, keyed by name. */
     private String name;
 
     /**
@@ -44,15 +46,18 @@
      * <p>
      * The manager is a singleton.
      * <p>
-     * One disk cache is returned per region fromt he maanger.
+     * One disk cache is returned per region from the manager.
      * <p>
      * @param iaca
      * @param cacheMgr This allows auxiliaries to reference the manager without assuming that it is
-     *            a singleton. This will allow JCS to be a nonsingleton. Also, it makes it easier to
-     *            test.
+     *            a singleton. This will allow JCS to be a non-singleton. Also, it makes it easier
+     *            to test.
+     * @param cacheEventLogger
+     * @param elementSerializer
      * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes iaca, ICompositeCacheManager cacheMgr )
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes iaca, ICompositeCacheManager cacheMgr,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer )
     {
         BlockDiskCacheAttributes idca = (BlockDiskCacheAttributes) iaca;
         if ( log.isDebugEnabled() )

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCache.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCache.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCache.java Wed Aug 13 15:14:46 2008
@@ -114,6 +114,7 @@
     private long bytesFree = 0;
 
     private int hitCount = 0;
+       
 
     /**
      * Use this lock to synchronize reads and writes to the underlying storage mechansism.

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheAttributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheAttributes.java Wed Aug 13 15:14:46 2008
@@ -22,8 +22,7 @@
 import org.apache.jcs.auxiliary.disk.AbstractDiskCacheAttributes;
 
 /**
- * The configurator will set these values based on what is in the cache.ccf
- * file.
+ * The configurator will set these values based on what is in the cache.ccf file.
  * <p>
  * @author Aaron Smuts
  */
@@ -61,8 +60,7 @@
     private boolean UseDiskShrinker = true;
 
     /**
-     * @param userName
-     *            The userName to set.
+     * @param userName The userName to set.
      */
     public void setUserName( String userName )
     {
@@ -78,8 +76,7 @@
     }
 
     /**
-     * @param password
-     *            The password to set.
+     * @param password The password to set.
      */
     public void setPassword( String password )
     {
@@ -95,8 +92,7 @@
     }
 
     /**
-     * @param url
-     *            The url to set.
+     * @param url The url to set.
      */
     public void setUrl( String url )
     {
@@ -113,8 +109,7 @@
 
     /**
      * This is appended to the url.
-     * @param database
-     *            The database to set.
+     * @param database The database to set.
      */
     public void setDatabase( String database )
     {
@@ -130,8 +125,7 @@
     }
 
     /**
-     * @param driverClassName
-     *            The driverClassName to set.
+     * @param driverClassName The driverClassName to set.
      */
     public void setDriverClassName( String driverClassName )
     {
@@ -147,8 +141,7 @@
     }
 
     /**
-     * @param tableName
-     *            The tableName to set.
+     * @param tableName The tableName to set.
      */
     public void setTableName( String tableName )
     {
@@ -164,11 +157,9 @@
     }
 
     /**
-     * If this is true then the disk cache will check to see if the item already
-     * exists in the database. If it is false, it will try to insert. If the
-     * isnert fails it will try to update.
-     * @param testBeforeInsert
-     *            The testBeforeInsert to set.
+     * If this is true then the disk cache will check to see if the item already exists in the
+     * database. If it is false, it will try to insert. If the isnert fails it will try to update.
+     * @param testBeforeInsert The testBeforeInsert to set.
      */
     public void setTestBeforeInsert( boolean testBeforeInsert )
     {
@@ -184,8 +175,7 @@
     }
 
     /**
-     * @param maxActive
-     *            The maxActive to set.
+     * @param maxActive The maxActive to set.
      */
     public void setMaxActive( int maxActive )
     {
@@ -201,8 +191,7 @@
     }
 
     /**
-     * @param shrinkerIntervalSecondsArg
-     *            The shrinkerIntervalSeconds to set.
+     * @param shrinkerIntervalSecondsArg The shrinkerIntervalSeconds to set.
      */
     public void setShrinkerIntervalSeconds( int shrinkerIntervalSecondsArg )
     {
@@ -218,8 +207,7 @@
     }
 
     /**
-     * @param useDiskShrinker
-     *            The useDiskShrinker to set.
+     * @param useDiskShrinker The useDiskShrinker to set.
      */
     public void setUseDiskShrinker( boolean useDiskShrinker )
     {
@@ -236,6 +224,8 @@
 
     /**
      * For debugging.
+     * <p>
+     * @return debug string with most of the properties.
      */
     public String toString()
     {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -22,7 +22,9 @@
 import org.apache.jcs.auxiliary.AuxiliaryCache;
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
  * This factory should create mysql disk caches.
@@ -36,8 +38,15 @@
 
     /**
      * This factory method should create an instance of the mysqlcache.
+     * <p>
+     * @param rawAttr 
+     * @param arg1 
+     * @param cacheEventLogger 
+     * @param elementSerializer 
+     * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes rawAttr, ICompositeCacheManager arg1 )
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes rawAttr, ICompositeCacheManager arg1,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer )
     {
         JDBCDiskCacheManager mgr = JDBCDiskCacheManager.getInstance( (JDBCDiskCacheAttributes) rawAttr );
         return mgr.getCache( (JDBCDiskCacheAttributes) rawAttr );
@@ -45,6 +54,8 @@
 
     /**
      * The name of the factory.
+     * <p>
+     * @param nameArg 
      */
     public void setName( String nameArg )
     {
@@ -53,6 +64,8 @@
 
     /**
      * Returns the display name
+     * <p>
+     * @return String
      */
     public String getName()
     {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/hsql/HSQLDiskCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/hsql/HSQLDiskCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/hsql/HSQLDiskCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/hsql/HSQLDiskCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -34,7 +34,9 @@
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
 import org.apache.jcs.auxiliary.disk.jdbc.JDBCDiskCacheAttributes;
 import org.apache.jcs.auxiliary.disk.jdbc.JDBCDiskCacheManager;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
  * This factory should create mysql disk caches.
@@ -44,6 +46,7 @@
 public class HSQLDiskCacheFactory
     implements AuxiliaryCacheFactory
 {
+    /** The logger */
     private final static Log log = LogFactory.getLog( HSQLDiskCacheFactory.class );
 
     private String name = "HSQLDiskCacheFactory";
@@ -52,8 +55,15 @@
 
     /**
      * This factory method should create an instance of the mysqlcache.
+     * <p>
+     * @param rawAttr
+     * @param arg1
+     * @param cacheEventLogger
+     * @param elementSerializer
+     * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes rawAttr, ICompositeCacheManager arg1 )
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes rawAttr, ICompositeCacheManager arg1,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer )
     {
         JDBCDiskCacheManager mgr = JDBCDiskCacheManager.getInstance( (JDBCDiskCacheAttributes) rawAttr );
         try
@@ -70,6 +80,8 @@
 
     /**
      * The name of the factory.
+     * <p>
+     * @param nameArg
      */
     public void setName( String nameArg )
     {
@@ -78,6 +90,8 @@
 
     /**
      * Returns the display name
+     * <p>
+     * @return name
      */
     public String getName()
     {
@@ -85,8 +99,7 @@
     }
 
     /**
-     * Creates the database if it doesn't exist, registers the driver class,
-     * etc.
+     * Creates the database if it doesn't exist, registers the driver class, etc.
      * <p>
      * @param attributes
      * @throws Exception

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheAttributes.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheAttributes.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheAttributes.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheAttributes.java Wed Aug 13 15:14:46 2008
@@ -91,6 +91,8 @@
 
     /**
      * For debugging.
+     * <p>
+     * @return debug string
      */
     public String toString()
     {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLDiskCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -22,7 +22,9 @@
 import org.apache.jcs.auxiliary.AuxiliaryCache;
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
  * This factory should create mysql disk caches.
@@ -40,9 +42,12 @@
      * <p>
      * @param rawAttr 
      * @param cacheManager 
+     * @param cacheEventLogger 
+     * @param elementSerializer 
      * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes rawAttr, ICompositeCacheManager cacheManager )
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes rawAttr, ICompositeCacheManager cacheManager,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer )
     {
         MySQLDiskCacheManager mgr = MySQLDiskCacheManager.getInstance( (MySQLDiskCacheAttributes) rawAttr );
         return mgr.getCache( (MySQLDiskCacheAttributes) rawAttr );

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLTableOptimizer.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLTableOptimizer.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLTableOptimizer.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/mysql/MySQLTableOptimizer.java Wed Aug 13 15:14:46 2008
@@ -31,31 +31,33 @@
 import org.apache.jcs.auxiliary.disk.jdbc.TableState;
 
 /**
- * The MySQL Table Optimizer can optimize MySQL tables. It knows how to optimize
- * for MySQL datbases in particular and how to repari the table if it is
- * corrupted in the process.
+ * The MySQL Table Optimizer can optimize MySQL tables. It knows how to optimize for MySQL datbases
+ * in particular and how to repari the table if it is corrupted in the process.
  * <p>
- * We will probably be able to abstract out a generic optimizer interface from
- * this class in the future.
+ * We will probably be able to abstract out a generic optimizer interface from this class in the
+ * future.
  * <p>
  * @author Aaron Smuts
  */
 public class MySQLTableOptimizer
 {
+    /** The logger */
     private final static Log log = LogFactory.getLog( MySQLTableOptimizer.class );
 
+    /** The pool */
     private JDBCDiskCachePoolAccess poolAccess = null;
 
+    /** The name of the table. */
     private String tableName = null;
 
+    /** optimizing, etc. */
     private TableState tableState;
 
     /**
      * This constructs an optimizer with the disk cacn properties.
      * <p>
      * @param attributes
-     * @param tableState
-     *            We mark the table status as optimizing when this is happening.
+     * @param tableState We mark the table status as optimizing when this is happening.
      */
     public MySQLTableOptimizer( MySQLDiskCacheAttributes attributes, TableState tableState )
     {
@@ -99,14 +101,12 @@
     }
 
     /**
-     * A scheduler will call this method. When it is called the table state is
-     * marked as optimizing. TODO we need to verify that no deletions are
-     * running before we call optimize. We should wait if a deletion is in
-     * progress.
+     * A scheduler will call this method. When it is called the table state is marked as optimizing.
+     * TODO we need to verify that no deletions are running before we call optimize. We should wait
+     * if a deletion is in progress.
      * <p>
-     * This restores when there is an optimization error. The error output looks
-     * like this:
-     *
+     * This restores when there is an optimization error. The error output looks like this:
+     * 
      * <pre>
      *           mysql&gt; optimize table JCS_STORE_FLIGHT_OPTION_ITINERARY;
      *               +---------------------------------------------+----------+----------+---------------------+
@@ -117,9 +117,9 @@
      *               +---------------------------------------------+----------+----------+---------------------+
      *               2 rows in set (51.78 sec)
      * </pre>
-     *
+     * 
      * A successful repair response looks like this:
-     *
+     * 
      * <pre>
      *        mysql&gt; REPAIR TABLE JCS_STORE_FLIGHT_OPTION_ITINERARY;
      *            +---------------------------------------------+--------+----------+----------------------------------------------+
@@ -131,9 +131,9 @@
      *            +---------------------------------------------+--------+----------+----------------------------------------------+
      *            3 rows in set (3 min 5.94 sec)
      * </pre>
-     *
+     * 
      * A successful optimization looks like this:
-     *
+     * 
      * <pre>
      *       mysql&gt; optimize table JCS_STORE_DEFAULT;
      *           +-----------------------------+----------+----------+----------+
@@ -143,8 +143,7 @@
      *           +-----------------------------+----------+----------+----------+
      *           1 row in set (1.10 sec)
      * </pre>
-     *
-     * @return
+     * @return true if it worked
      */
     public boolean optimizeTable()
     {
@@ -294,8 +293,8 @@
     /**
      * This is called if the optimizatio is in error.
      * <p>
-     * It looks for "OK" in response. If it find "OK" as a message in any result
-     * set row, it returns true. Otherwise we assume that the repair failed.
+     * It looks for "OK" in response. If it find "OK" as a message in any result set row, it returns
+     * true. Otherwise we assume that the repair failed.
      * <p>
      * @param sStatement
      * @return true if successful
@@ -337,8 +336,7 @@
     }
 
     /**
-     * @param tableName
-     *            The tableName to set.
+     * @param tableName The tableName to set.
      */
     public void setTableName( String tableName )
     {

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCache.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCache.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCache.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCache.java Wed Aug 13 15:14:46 2008
@@ -190,7 +190,7 @@
      * handle with a zombie.
      * <p>
      * @param key
-     * @return
+     * @return false always
      * @throws IOException
      */
     public boolean remove( Serializable key )

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractFactory.java Wed Aug 13 15:14:46 2008
@@ -23,7 +23,9 @@
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
 import org.apache.jcs.auxiliary.lateral.behavior.ILateralCacheAttributes;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 
 /**
@@ -42,13 +44,20 @@
 public abstract class LateralCacheAbstractFactory
 	implements AuxiliaryCacheFactory
 {
-
+    /** The auxiliary name */
     private String name;
 
-    /* (non-Javadoc)
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheFactory#createCache(org.apache.jcs.auxiliary.AuxiliaryCacheAttributes, org.apache.jcs.engine.behavior.ICompositeCacheManager)
+    /**
+     * Creates a lateral cache.
+     * <p>
+     * @param attr
+     * @param cacheMgr
+     * @param cacheEventLogger 
+     * @param elementSerializer 
+     * @return AuxiliaryCache
      */
-    public abstract AuxiliaryCache createCache( AuxiliaryCacheAttributes attr, ICompositeCacheManager cacheMgr );
+    public abstract AuxiliaryCache createCache( AuxiliaryCacheAttributes attr, ICompositeCacheManager cacheMgr,
+                                                ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer );
 
     /**
      * Makes sure a listener gets created. It will get monitored as soon as it

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractManager.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractManager.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractManager.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheAbstractManager.java Wed Aug 13 15:14:46 2008
@@ -44,7 +44,7 @@
  * <p>
  *
  * @TODO: - need freeCache, release, getStats - need to find an interface
- *        acceptible for all - cache managers or a manager within a type
+ *        Acceptable for all - cache managers or a manager within a type
  */
 public abstract class LateralCacheAbstractManager
     implements ILateralCacheManager

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWait.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWait.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWait.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWait.java Wed Aug 13 15:14:46 2008
@@ -39,7 +39,9 @@
 import org.apache.jcs.engine.CacheConstants;
 import org.apache.jcs.engine.CacheEventQueueFactory;
 import org.apache.jcs.engine.behavior.ICacheElement;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICacheEventQueue;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 import org.apache.jcs.engine.stats.StatElement;
 import org.apache.jcs.engine.stats.Stats;
 import org.apache.jcs.engine.stats.behavior.IStatElement;
@@ -52,8 +54,10 @@
 public class LateralCacheNoWait
     implements AuxiliaryCache
 {
+    /** Don't change */
     private static final long serialVersionUID = -7251187566116178475L;
 
+    /** The logger. */
     private final static Log log = LogFactory.getLog( LateralCacheNoWait.class );
 
     private final LateralCache cache;
@@ -65,6 +69,12 @@
     private int removeCount = 0;
 
     private int putCount = 0;
+    
+    /** An optional event logger */
+    private ICacheEventLogger cacheEventLogger;    
+    
+    /** The serializer. */
+    private IElementSerializer elementSerializer;       
 
     /**
      * Constructs with the given lateral cache, and fires up an event queue for aysnchronous
@@ -315,6 +325,27 @@
     }
 
     /**
+     * Allows it to be injected.
+     * <p>
+     * @param cacheEventLogger
+     */
+    public void setCacheEventLogger( ICacheEventLogger cacheEventLogger )
+    {
+        this.cacheEventLogger = cacheEventLogger;
+    }   
+    
+    /**
+     * Allows you to inject a custom serializer. A good example would be a compressing standard
+     * serializer.
+     * <p>
+     * @param elementSerializer
+     */
+    public void setElementSerializer( IElementSerializer elementSerializer )
+    {
+        this.elementSerializer = elementSerializer;
+    }
+    
+    /**
      * getStats
      * @return String
      */

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWaitFacade.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWaitFacade.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWaitFacade.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/LateralCacheNoWaitFacade.java Wed Aug 13 15:14:46 2008
@@ -36,18 +36,19 @@
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.lateral.behavior.ILateralCacheAttributes;
 import org.apache.jcs.engine.behavior.ICacheElement;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICacheType;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 import org.apache.jcs.engine.stats.StatElement;
 import org.apache.jcs.engine.stats.Stats;
 import org.apache.jcs.engine.stats.behavior.IStatElement;
 import org.apache.jcs.engine.stats.behavior.IStats;
 
 /**
- * Used to provide access to multiple services under nowait protection.
- * Composite factory should construct LateralCacheNoWaitFacade to give to the
- * composite cache out of caches it constructs from the varies manager to
- * lateral services. Perhaps the lateralcache factory should be able to do this.
- *
+ * Used to provide access to multiple services under nowait protection. Composite factory should
+ * construct LateralCacheNoWaitFacade to give to the composite cache out of caches it constructs
+ * from the varies manager to lateral services. Perhaps the lateralcache factory should be able to
+ * do this.
  */
 public class LateralCacheNoWaitFacade
     implements AuxiliaryCache
@@ -64,9 +65,16 @@
     private ILateralCacheAttributes lateralCacheAttributes;
 
     /**
-     * Constructs with the given lateral cache, and fires events to any
-     * listeners.
-     *
+     * An optional event logger. Only errors are logged here. We don't want to log ICacheEvents
+     * since the noWaits do this.
+     */
+    private ICacheEventLogger cacheEventLogger;
+    
+    /** The serializer. */
+    private IElementSerializer elementSerializer;        
+
+    /**
+     * Constructs with the given lateral cache, and fires events to any listeners.
      * @param noWaits
      * @param cattr
      */
@@ -180,7 +188,8 @@
      * Gets multiple items from the cache based on the given set of keys.
      * <p>
      * @param keys
-     * @return a map of Serializable key to ICacheElement element, or an empty map if there is no data in cache for any of these keys
+     * @return a map of Serializable key to ICacheElement element, or an empty map if there is no
+     *         data in cache for any of these keys
      */
     public Map getMultiple( Set keys )
     {
@@ -290,7 +299,6 @@
 
     /**
      * No lateral invokation.
-     *
      * @return The size value
      */
     public int getSize()
@@ -301,7 +309,6 @@
 
     /**
      * Gets the cacheType attribute of the LateralCacheNoWaitFacade object
-     *
      * @return The cacheType value
      */
     public int getCacheType()
@@ -311,7 +318,6 @@
 
     /**
      * Gets the cacheName attribute of the LateralCacheNoWaitFacade object
-     *
      * @return The cacheName value
      */
     public String getCacheName()
@@ -323,7 +329,6 @@
     // need to do something with this
     /**
      * Gets the status attribute of the LateralCacheNoWaitFacade object
-     *
      * @return The status value
      */
     public int getStatus()
@@ -340,10 +345,29 @@
         return this.lateralCacheAttributes;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see java.lang.Object#toString()
+    /**
+     * Allows it to be injected.
+     * <p>
+     * @param cacheEventLogger
+     */
+    public void setCacheEventLogger( ICacheEventLogger cacheEventLogger )
+    {
+        this.cacheEventLogger = cacheEventLogger;
+    }
+
+    /**
+     * Allows you to inject a custom serializer. A good example would be a compressing standard
+     * serializer.
+     * <p>
+     * @param elementSerializer
+     */
+    public void setElementSerializer( IElementSerializer elementSerializer )
+    {
+        this.elementSerializer = elementSerializer;
+    }
+
+    /**
+     * @return "LateralCacheNoWaitFacade: " + cacheName;
      */
     public String toString()
     {
@@ -352,7 +376,6 @@
 
     /**
      * getStats
-     *
      * @return String
      */
     public String getStats()

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/behavior/ILateralCacheManager.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/behavior/ILateralCacheManager.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/behavior/ILateralCacheManager.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/behavior/ILateralCacheManager.java Wed Aug 13 15:14:46 2008
@@ -25,8 +25,8 @@
 import org.apache.jcs.auxiliary.AuxiliaryCacheManager;
 
 /**
- * This helps ensure some common behvior among LateraLCacheManagers for things
- * such as montiors.
+ * This helps ensure some common behavior among LateraLCacheManagers for things
+ * such as monitors.
  * <p>
  * @author Aaron Smuts
  */
@@ -34,21 +34,24 @@
     extends AuxiliaryCacheManager
 {
     /**
-     * This is a temporary solution that allos the monitor to get the instances
+     * This is a temporary solution that allows the monitor to get the instances
      * of a manager.
-     * @return
+     * <p>
+     * @return Map
      */
     public abstract Map getInstances();
 
     /**
-     * This is a temporary solution that allos the monitor to get caches from an
+     * This is a temporary solution that allows the monitor to get caches from an
      * instance of a manager.
-     * @return
+     * <p>
+     * @return Map
      */
     public abstract Map getCaches();
 
     /**
-     * The restore calls thsi on the manger if a cache if found to be in error.
+     * The restore calls this on the manger if a cache if found to be in error.
+     * <p>
      * @return Object is the service if it can be fixed.
      * @throws IOException
      *             if the service cannot be fixed.
@@ -57,11 +60,11 @@
         throws IOException;
 
     /**
-     * Sets the corected service. The restore process will call this if it gets
+     * Sets the corrected service. The restore process will call this if it gets
      * a good service back from fixService.
+     * <p>
      * @param lateralService
      * @param lateralWatch
      */
     public void fixCaches( ILateralCacheService lateralService, ILateralCacheObserver lateralWatch );
-
 }

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/socket/tcp/LateralTCPCacheFactory.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/socket/tcp/LateralTCPCacheFactory.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/socket/tcp/LateralTCPCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/lateral/socket/tcp/LateralTCPCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -34,30 +34,34 @@
 import org.apache.jcs.auxiliary.lateral.socket.tcp.discovery.UDPDiscoveryManager;
 import org.apache.jcs.auxiliary.lateral.socket.tcp.discovery.UDPDiscoveryService;
 import org.apache.jcs.engine.behavior.ICache;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
- * Constructs a LateralCacheNoWaitFacade for the given configuration. Each
- * lateral service / local relationship is managed by one manager. This manager
- * can have multiple caches. The remote relationships are consolidated and
- * restored via these managers.
+ * Constructs a LateralCacheNoWaitFacade for the given configuration. Each lateral service / local
+ * relationship is managed by one manager. This manager can have multiple caches. The remote
+ * relationships are consolidated and restored via these managers.
  * <p>
- * The facade provides a front to the composite cache so the implementation is
- * transparent.
- *
+ * The facade provides a front to the composite cache so the implementation is transparent.
  */
 public class LateralTCPCacheFactory
     extends LateralCacheAbstractFactory
 {
+    /** The logger */
     private final static Log log = LogFactory.getLog( LateralTCPCacheFactory.class );
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.AuxiliaryCacheFactory#createCache(org.apache.jcs.auxiliary.AuxiliaryCacheAttributes,
-     *      org.apache.jcs.engine.behavior.ICompositeCacheManager)
+    /**
+     * Creates a TCP lateral.
+     * <p>
+     * @param iaca
+     * @param cacheMgr
+     * @param cacheEventLogger
+     * @param elementSerializer
+     * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes iaca, ICompositeCacheManager cacheMgr )
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes iaca, ICompositeCacheManager cacheMgr,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer )
     {
         ITCPLateralCacheAttributes lac = (ITCPLateralCacheAttributes) iaca;
         ArrayList noWaits = new ArrayList();
@@ -101,7 +105,7 @@
 
         // create the no wait facade.
         LateralCacheNoWaitFacade lcnwf = new LateralCacheNoWaitFacade( (LateralCacheNoWait[]) noWaits
-            .toArray( new LateralCacheNoWait[0] ), (ILateralCacheAttributes)iaca );
+            .toArray( new LateralCacheNoWait[0] ), (ILateralCacheAttributes) iaca );
 
         // create udp discovery if available.
         createDiscoveryService( lac, lcnwf, cacheMgr );
@@ -109,11 +113,9 @@
         return lcnwf;
     }
 
-    /*
-     * (non-Javadoc)
-     *
-     * @see org.apache.jcs.auxiliary.lateral.LateralCacheAbstractFactory#createListener(org.apache.jcs.auxiliary.lateral.LateralCacheAttributes,
-     *      org.apache.jcs.engine.behavior.ICompositeCacheManager)
+    /**
+     * @param lac
+     * @param cacheMgr
      */
     public void createListener( ILateralCacheAttributes lac, ICompositeCacheManager cacheMgr )
     {
@@ -146,17 +148,15 @@
     }
 
     /**
-     * Creates the discovery service. Only creates this for tcp laterals right
-     * now.
-     *
-     * @param lac
-     *            ITCPLateralCacheAttributes
+     * Creates the discovery service. Only creates this for tcp laterals right now.
+     * <p>
+     * @param lac ITCPLateralCacheAttributes
      * @param lcnwf
      * @param cacheMgr
      * @return null if none is created.
      */
     private UDPDiscoveryService createDiscoveryService( ITCPLateralCacheAttributes lac, LateralCacheNoWaitFacade lcnwf,
-                                                       ICompositeCacheManager cacheMgr )
+                                                        ICompositeCacheManager cacheMgr )
     {
         UDPDiscoveryService discovery = null;
 



---------------------------------------------------------------------
To unsubscribe, e-mail: jcs-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: jcs-dev-help@jakarta.apache.org
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -1,60 +1,54 @@
 package org.apache.jcs.auxiliary;
 
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
- *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
+ * agreements. See the NOTICE file distributed with this work for additional information regarding
+ * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the License. You may obtain a
+ * copy of the License at
+ * 
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
- * All auxiliary caches must have a factory that the cache configurator can use
- * to create instances.
- *
+ * All auxiliary caches must have a factory that the cache configurator can use to create instances.
  */
 public interface AuxiliaryCacheFactory
 {
-
     /**
-     *
+     * Creates an auxiliary using the supplied attributes. Adds it to the composite cache manager.
+     * <p>
      * @param attr
      *
      * @param cacheMgr
      *            This allows auxiliaries to reference the manager without
      *            assuming that it is a singleton. This will allow JCS to be a
      *            nonsingleton. Also, it makes it easier to test.
      *
      * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes attr, ICompositeCacheManager cacheMgr );
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes attr, ICompositeCacheManager cacheMgr,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer );
 
     /**
      * Sets the name attribute of the AuxiliaryCacheFactory object
-     *
-     * @param s
-     *            The new name value
+     * <p>
+     * @param s The new name value
      */
     public void setName( String s );
 
     /**
      * Gets the name attribute of the AuxiliaryCacheFactory object
-     *
+     * <p>
      * @return The name value
      */
     public String getName();
-
 }
@@ -1,60 +1,54 @@
      * @param attr
-     *
-     * @param cacheMgr
-     *            This allows auxiliaries to reference the manager without
-     *            assuming that it is a singleton. This will allow JCS to be a
-     *            nonsingleton. Also, it makes it easier to test.
-     *
+     * @param cacheMgr This allows auxiliaries to reference the manager without assuming that it is
+     *            a singleton. This will allow JCS to be a nonsingleton. Also, it makes it easier to
+     *            test.
+     * @param cacheEventLogger 
+     * @param elementSerializer 
      * @return AuxiliaryCache
      */

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheManager.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/AuxiliaryCacheManager.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================
--- jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCacheFactory.java (original)
+++ jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/indexed/IndexedDiskCacheFactory.java Wed Aug 13 15:14:46 2008
@@ -24,7 +24,9 @@
 import org.apache.jcs.auxiliary.AuxiliaryCache;
 import org.apache.jcs.auxiliary.AuxiliaryCacheAttributes;
 import org.apache.jcs.auxiliary.AuxiliaryCacheFactory;
+import org.apache.jcs.engine.behavior.ICacheEventLogger;
 import org.apache.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
  * Creates disk cache instances.
@@ -32,26 +34,30 @@
 public class IndexedDiskCacheFactory
     implements AuxiliaryCacheFactory
 {
+    /** The logger. */
     private final static Log log = LogFactory.getLog( IndexedDiskCacheFactory.class );
 
+    /** The auxiliary name. */
     private String name;
 
     /**
-     * Get an instance of the IndexDiskCacheManager for the attributes and then
-     * get an IndexedDiskCache from the manager.
+     * Get an instance of the IndexDiskCacheManager for the attributes and then get an
+     * IndexedDiskCache from the manager.
      * <p>
      * The manager is a singleton.
      * <p>
-     * One disk cache is returned per region fromt he maanger.
+     * One disk cache is returned per region from the manager.
      * <p>
      * @param iaca
      * @param cacheMgr
      *            This allows auxiliaries to reference the manager without
      *            assuming that it is a singleton. This will allow JCS to be a
      *            nonsingleton. Also, it makes it easier to test.
      * @return AuxiliaryCache
      */
-    public AuxiliaryCache createCache( AuxiliaryCacheAttributes iaca, ICompositeCacheManager cacheMgr )
+    public AuxiliaryCache createCache( AuxiliaryCacheAttributes iaca, ICompositeCacheManager cacheMgr,
+                                       ICacheEventLogger cacheEventLogger, IElementSerializer elementSerializer )
     {
         IndexedDiskCacheAttributes idca = (IndexedDiskCacheAttributes) iaca;
         if ( log.isDebugEnabled() )
@@ -75,8 +81,7 @@
     /**
      * Sets the name attribute of the DiskCacheFactory object
      * <p>
-     * @param name
-     *            The new name value
+     * @param name The new name value
      */
     public void setName( String name )
     {
@@ -32,26 +34,30 @@
      * <p>
      * @param iaca
-     * @param cacheMgr
-     *            This allows auxiliaries to reference the manager without
-     *            assuming that it is a singleton. This will allow JCS to be a
-     *            nonsingleton. Also, it makes it easier to test.
+     * @param cacheMgr This allows auxiliaries to reference the manager without assuming that it is
+     *            a singleton. This will allow JCS to be a non-singleton. Also, it makes it easier to
+     *            test.
+     * @param cacheEventLogger 
+     * @param elementSerializer 
      * @return AuxiliaryCache
      */

Modified: jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheAttributes.java
URL: http://svn.apache.org/viewvc/jakarta/jcs/trunk/src/java/org/apache/jcs/auxiliary/disk/jdbc/JDBCDiskCacheAttributes.java?rev=685702&r1=685701&r2=685702&view=diff
==============================================================================